@@ -3,10 +3,10 @@ import json
 from micloud.micloud import MiCloud
 
 @click.command()
-@click.option('--country', default='de', help='Language code of the server to query. Default: "de"')
+@click.option('--username', '-u', prompt=True, help='Your Xiaomi username.')
+@click.option('--password', '-p', prompt=True, hide_input=True, confirmation_prompt=False)
+@click.option('--country', '-c', default='de', help='Language code of the server to query. Default: "de"')
 @click.option('--pretty', is_flag=True, help='Pretty print json output.')
-@click.argument('username')
-@click.argument('password')
 def get_devices(username, password, country, pretty):
     mc = MiCloud(username, password)
     mc.login()
